@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2015-07-02'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 use 5.010001;
 use strict;
@@ -194,6 +194,10 @@ _
             'x.schema.element_entity' => 'modulename',
         },
 
+        code_after_shebang => {
+            schema => 'str*',
+            tags => ['category:extra-code'],
+        },
         code_before_parse_cmdline_options => {
             schema => 'str*',
             tags => ['category:extra-code'],
@@ -714,6 +718,8 @@ _
             "",
             $shebang_line, "\n",
 
+            ("# code_after_shebang\n\n", $args{code_after_shebang}, "\n") x !!$args{code_after_shebang},
+
             "# PERICMD_INLINE_SCRIPT: ", dmp(\%args), "\n\n",
 
             "# This script is generated by ", __PACKAGE__,
@@ -745,7 +751,7 @@ _
                 sort keys %{$cd->{subs}}),
             "\n",
 
-            ("# code before parse cmdline options \n\n", $args{code_before_parse_cmdline_options}) x !!$args{code_before_parse_cmdline_options},
+            ("# code_before_parse_cmdline_options\n\n", $args{code_before_parse_cmdline_options}, "\n") x !!$args{code_before_parse_cmdline_options},
 
             @l,
 
@@ -801,7 +807,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.11 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-02.
+This document describes version 0.12 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-02.
 
 =head1 SYNOPSIS
 
@@ -827,23 +833,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                   Rate  run 1 (lite) run --version (lite)   -c (lite) run --version (inline) run 1 (inline) -c (inline)   perl
- run 1 (lite)           13.715+-0.017/s            --               -61.2%      -81.4%                 -88.2%         -88.9%      -90.7% -97.2%
- run --version (lite)   35.355+-0.032/s 157.78+-0.39%                   --      -52.2%                 -69.6%         -71.4%      -76.1% -92.8%
- -c (lite)                73.89+-0.46/s   438.7+-3.4%            109+-1.3%          --                 -36.4%         -40.2%      -50.1% -84.9%
- run --version (inline)    116.3+-3.8/s      748+-28%             229+-11%  57.4+-5.3%                     --          -5.9%      -21.5% -76.3%
- run 1 (inline)          123.51+-0.58/s   800.5+-4.4%          249.3+-1.7%  67.2+-1.3%              6.2+-3.5%             --      -16.7% -74.8%
- -c (inline)               148.2+-2.3/s      981+-17%          319.2+-6.6% 100.6+-3.4%             27.5+-4.6%         20+-2%          -- -69.7%
- perl                    489.67+-0.97/s  3470.3+-8.3%             1285+-3% 562.7+-4.3%               321+-14%      296.5+-2% 230.4+-5.3%     --
+                                   Rate run 1 (lite) run --version (lite)  -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)           13.673+-0.021/s           --               -61.2%     -79.8%         -89.1%                 -91.3%      -91.3% -97.2%
+ run --version (lite)   35.274+-0.042/s 157.99+-0.5%                   --     -47.9%         -71.8%                 -77.6%      -77.7% -92.9%
+ -c (lite)                  67.8+-1.3/s  395.6+-9.3%           92.1+-3.6%         --         -45.8%                 -56.9%      -57.1% -86.3%
+ run 1 (inline)           125.08+-0.3/s  814.8+-2.6%        254.59+-0.96% 84.6+-3.5%             --                 -20.4%      -20.8% -74.7%
+ run --version (inline)  157.17+-0.34/s   1049.5+-3%          345.6+-1.1%  132+-4.4%   25.65+-0.41%                     --       -0.4% -68.2%
+ -c (inline)               157.9+-2.7/s    1055+-20%          347.5+-7.7%  133+-5.9%     26.2+-2.2%              0.4+-1.7%          -- -68.1%
+ perl                        494.7+-2/s    3518+-15%         1302.5+-5.8%   630+-14%    295.5+-1.8%            214.8+-1.4% 213.4+-5.5%     --
  
  Average times:
-   perl                  :     2.0422ms
-   -c (inline)           :     6.7476ms
-   run 1 (inline)        :     8.0965ms
-   run --version (inline):     8.5985ms
-   -c (lite)             :    13.5336ms
-   run --version (lite)  :    28.2845ms
-   run 1 (lite)          :    72.9129ms
+   perl                  :     2.0214ms
+   -c (inline)           :     6.3331ms
+   run --version (inline):     6.3625ms
+   run 1 (inline)        :     7.9949ms
+   -c (lite)             :    14.7493ms
+   run --version (lite)  :    28.3495ms
+   run 1 (lite)          :    73.1368ms
 
 =head1 FUNCTIONS
 
@@ -911,6 +917,8 @@ Arguments ('*' denotes required arguments):
 
 Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
+=item * B<code_after_shebang> => I<str>
+
 =item * B<code_before_parse_cmdline_options> => I<str>
 
 =item * B<common_opts> => I<any>
